%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%        Harding and Pagan Analysis on selected variables;     %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('file dw_turningpoints.m')


nsim = 1000; % no. of simulations

disp('nsim =')
disp(nsim)

ZT=7;    % No of variables
I=1;

ADPP=zeros(nsim,ZT);
ADTT=zeros(nsim,ZT);
ADPT=zeros(nsim,ZT);
ADTP=zeros(nsim,ZT);
RATIO=zeros(nsim,ZT);
GRRATEPT=zeros(nsim,ZT);
GRRATETP=zeros(nsim,ZT);
GRRATIO=zeros(nsim,ZT);
cumrec=zeros(nsim,ZT);
cumexp=zeros(nsim,ZT);

for zt = 1:nsim;

    options_.simul_seed = 1000+zt*1100;
    options_.periods = 566;
    options_.drop       = 400;
    stoch_simul(M_,options_,oo_, var_list_); %IEB ADDED this line   
    % WAS: stoch_simul(var_list_);

%Transform simulation output into trending data
growth   = g*ones(options_.periods,1);
lPROD    = cumprod(growth);
lOUT     = lPROD.*ytot;
lCONS    = lPROD.*c;
lINV     = lPROD.*inv;
lLABPROD = lPROD.*ytot./n;
lWR      = lPROD.*wr;
ldata        = [lOUT n ur pie piew nint lINV];
ldata        = ldata(options_.drop+M_.maximum_lag+1:end,:);
ldatanames    = strvcat('lOUT','n','ur','pie','piew','nint','linv');
[t V]        = size(ldata);

% Apply hp-filter for consistency with data
trenddata    = hpfilter(log(ldata),Smoothing=1600);
ldata    = exp(log(ldata)-trenddata); %Need to take exp for consistency 
    % with the program mBBQSF_model, where the data is transformed in logs

% Preparing Harding-Pagan code
%I = 1 economy
    I=1;
%Real time line
    t=t/I;
    
% Harding-Pagan style analysis 
F=1; % quarterly frequency
[dating state]=mBBQinput_model(ldata,I);

%Duration and steepness of cycles
G=0; % G=1 for continous compounding ; G=0 for quarterly growth rates
for  va=1:size(dating,2);
    date = dating(:,va);
ADPP(zt,va)=adpp(ldata(:,va),F,date);
ADTT(zt,va)=adtt(ldata(:,va),F,date);
ADPT(zt,va)=adpt(ldata(:,va),F,date);
ADTP(zt,va)=adtp(ldata(:,va),F,date);

RATIO(zt,va)=ADTP(zt,va)./ADPT(zt,va);

GRRATEPT(zt,va)=grratept(ldata(:,va),F,G,date);
GRRATETP(zt,va)=grratetp(ldata(:,va),F,G,date);
GRRATIO(zt,va)=abs(GRRATETP(zt,va)./GRRATEPT(zt,va));
cumrec(zt,va)=GRRATEPT(zt,va).*ADPT(zt,va);
cumexp(zt,va)=GRRATETP(zt,va).*ADTP(zt,va);
end

    
end

MPP=mean(ADPP);
MTT=mean(ADTT);
MPT=mean(ADPT);
MTP=mean(ADTP);

MGRTP=nanmean(GRRATETP)*4; %in annualized growth
MGRPT=nanmean(GRRATEPT)*4; %in annualized growth

MRATIO=MTP./MPT;
MGRRATIO=abs(MGRTP./MGRPT);

Mcumrec=mean(cumrec);
Mcumexp=mean(cumexp);

Turning = [MPP' MTT' MPT' MTP' MRATIO' MGRPT' MGRTP' MGRRATIO' Mcumrec' Mcumexp'];

title1=['Turning point analysis'];
disp(title1); %IEB ADDED this line
%IEB: removed 'strvcat' and changed () to {} (to ensure 'headerst' is a
% cell array of character vectors. AND removed 'variable' as a column name
% so that length of 'headerst' matches number of columns in 'Turning'
headerst={'ADPP','ADTT','ADPT','ADTP','RATIO','GRRATEPT','GRRATETP','GRRATIO','cum-rec','cum-exp'};
%IEB: WAS -> table(title1, headerst,ldatanames,Turning,size(headerst,2)+2,2,2);
%IEB: Modified to code below (added all lines b
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
Table= array2table(Turning,'VariableNames', headerst, 'RowNames', varnames);
disp(Table); %IEB: ADDED this line
