%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%        Moments selected variables;                           %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('file dwmoments.m')

nsim        = 1000;  % no. of simulations
ZT          = 11;    % No of variables %IEB: needs to be equal to size(ldata)
I           = 1;

disp('nsim =')
disp(nsim)

%% (IEB) Creat zeroe matrices to store statistical values of variables
%% for each simulation %%
STDEV    = zeros(nsim,ZT);
RelSTDEV_prod   = zeros(nsim,ZT);
RelSTDEV_gdp    = zeros(nsim,ZT);
SKEW            = zeros(nsim,ZT);
KURT            = zeros(nsim,ZT);
corhp_Y         = zeros(nsim,ZT);
corhp_PIE       = zeros(nsim,ZT);

meanqoq=zeros(nsim,ZT);
medianqoq=zeros(nsim,ZT);
stdqoq=zeros(nsim,ZT);
skewqoq=zeros(nsim,ZT);
kurtqoq=zeros(nsim,ZT);

meanyoy=zeros(nsim,ZT);
medianyoy=zeros(nsim,ZT);
stdyoy=zeros(nsim,ZT);
skewyoy=zeros(nsim,ZT);
kurtyoy=zeros(nsim,ZT);

for sim = 1:nsim;
    options_.simul_seed = 1000+sim*1100; %% IEB: sets seed value to ensure same random number generation each time
    options_.periods = 566; %% IEB: sets number of simulations, to have differnet starting points
    options_.drop    = 399; %%% IEB AMMENDED: changed from 400 to 399 to have 166 periods
    % IEB MODIFIED below: WAS -> 'stoch_simul(var_list_);
    [info, oo_, options_, M_] = stoch_simul(M_,options_,oo_, var_list_);  
    send_endogenous_variables_to_workspace % IEB ADDED this line
  
    

clear dataraw;
clear ldata;
clear logdata;

%Transform simulation output into trending data
growth   = g*ones(options_.periods,1);
lPROD    = cumprod(growth);
lOUT     = lPROD.*ytot;
lCONS    = lPROD.*c;
lINV     = lPROD.*inv;
lLABPROD = lPROD.*ytot./n;
lWR      = lPROD.*wr;

ldata        = [lLABPROD lOUT n ur pie piew lWR nint lINV v v./u];
ldata        = ldata(options_.drop+M_.maximum_lag+1:end,:);
ldatanames    = strvcat('labPro','lOUT','n','ur','pie','piew','lWR','nint','linv','v','tight');
[t V]        = size(ldata);


%% Moments HP detrended 
logdata      = log(ldata);

trenddata    = hpfilter(logdata,Smoothing=1600);
cycledata    = logdata-trenddata;

%HP detrended
STDEV(sim,:)           = nanstd(cycledata,0)*100; % volatilities in percentage deviations from HP
RelSTDEV_prod(sim,:)   = STDEV(sim,:)./STDEV(sim,1);
RelSTDEV_gdp(sim,:)    = STDEV(sim,:)./STDEV(sim,2);
SKEW(sim,:)            = skewness(cycledata,0);
KURT(sim,:)            = kurtosis(cycledata,0)-3;

% Computing correlations between variables:
corhp=[];
    corhp=corrcoef(cycledata(:,:));
clear time;

% Correlation of all variables with GDP 
    for v=1:V
    corhp_Y(sim,v)=corhp(v,2);
    end

% Correlation of all variables with pie  
    for v=1:V
    corhp_PIE(sim,v)=corhp(v,5);
    end
      

%% Moments of qoq and yoy growth rates

dataqoq = 100*[nan(1,size(ldata,2)); ldata(2:end,:)./ldata(1:end-1,:) - 1];
piepos  = strmatch('pie',ldatanames,'exact');
piewpos = strmatch('piew',ldatanames,'exact');
vpos    = strmatch('v',ldatanames,'exact');
dataqoq(2:end,[vpos]) = 100*ldata(2:end,[vpos]); % v are in levels
dataqoq(2:end,[piepos piewpos]) = 100*(ldata(2:end,[piepos piewpos])-1); % price and wage inflation

datayoy = 100*[nan(4,size(ldata,2)); ldata(5:end,:)./ldata(1:end-4,:) - 1]; 
datatmp = nan(size(ldata));
for i = 5:length(ldata)
    datatmp(i,piepos)  = prod(ldata(i-3:i,piepos ))-1; %price inflation
    datatmp(i,piewpos) = prod(ldata(i-3:i,piewpos))-1; %wage inflation
    datatmp(i,vpos)    = ldata(i,vpos)+ldata(i-1,vpos)+ldata(i-2,vpos)+ldata(i-3,vpos); % v are in levels
end
datayoy(5:end,[piepos piewpos vpos]) = 100*datatmp(5:end,[piepos piewpos vpos]);

meanqoq(sim,:) =nanmean(dataqoq);
medianqoq(sim,:) = nanmedian(dataqoq);
stdqoq(sim,:)=nanstd(dataqoq);
skewqoq(sim,:)=skewness(dataqoq);
kurtqoq(sim,:)=kurtosis(dataqoq)-3;

datayoy=datayoy(5:end,:);

meanyoy(sim,:) =nanmean(datayoy);
medianyoy(sim,:) = nanmedian(datayoy);
stdyoy(sim,:)=nanstd(datayoy);
skewyoy(sim,:)=skewness(datayoy);
kurtyoy(sim,:)=kurtosis(datayoy)-3;

end

%% Tables Moments HP-detrended % IEB: modified code to align with newer MatLab version

momdataraw      = [mean(STDEV); mean(RelSTDEV_prod); mean(RelSTDEV_gdp); mean(SKEW); mean(KURT)];
%%%%%%%%%
disp(' ')  %IEB: empty line 
%%%%%%%%%
title1=['Model Results - in % deviations from HP'];
disp(title1); %IEB ADDED this line
% IEB MODIFICATION BELOW: removed 'strvcat' and changed () to {}
labels ={'StDev','RelStDev_prod','RelStDev_gdp','Skewness','Kurtosis'};
% IEB MODIFICATION: WAS -->  
% table(title1,strvcat('var',ldatanames),labels,momdataraw,size(ldatanames,1)+2,2,4);
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
% IEB Added line below 
T1= array2table(momdataraw','VariableNames', labels, 'RowNames', varnames);
disp(T1); % IEB: ADDED this line.

title2=['Correlation with GDP'];
disp(title2); %IEB ADDED this line
corY=mean(corhp_Y);
label2 = {'Corr y'}; %IEB removed 'strvcat' and changed () to {}
% IEB MODIFICATION: WAS --> 
% table(title2, strvcat('var',ldatanames),label2,corY,size(ldatanames,1)+2,2,4)
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
% IEB Added line below 
T2= array2table(corY','VariableNames', label2, 'RowNames', varnames);
disp(T2); % IEB: ADDED this line.

corPIE=mean(corhp_PIE);
title3=['Correlation with PIE'];
disp(title3); %IEB ADDED this line
label3 = {'Corr pie'}; %IEB removed 'strvcat' and changed () to {}
% IEB MODIFICATION: WAS --> 
% table(title3, strvcat('var',ldatanames),label3,corPIE,size(ldatanames,1)+2,2,4)
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
% IEB Added line below 
T3= array2table(corPIE','VariableNames', label3, 'RowNames', varnames);
disp(T3); % IEB: ADDED this line.

%% Tables Moments in growth rates

momQOQ      = [mean(meanqoq); mean(medianqoq);mean(stdqoq); mean(skewqoq);mean(kurtqoq)];
momYOY      =  [mean(meanyoy); mean(medianyoy);mean(stdyoy); mean(skewyoy); mean(kurtyoy)];

%IEB changed 'labels' to 'label4'
label4 ={'Mean','Median','StDev','skewness','kurtosis'};%IEB removed 'strvcat' and changed () to {}

% IEB Modified title5 to title4
title4=['moments of qoq growth rates'];
disp(title4); %IEB ADDED this line
% IEB MODIFICATION: WAS --> 
% table(title5,strvcat('var',ldatanames),labels,momQOQ,size(ldatanames,2)+0,0,4);
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
% IEB Added line below 
T4= array2table(momQOQ','VariableNames', label4, 'RowNames', varnames);
disp(T4); % IEB: ADDED this line.

% IEB Modified title6 to title5
title5=['moments of yoy growth rates'];
disp(title5); %IEB ADDED this line
% IEB MODIFICATION: WAS --> 
%table(title6,strvcat('var',ldatanames),labels,momYOY,size(ldatanames,2)+0,0,4);
varnames = [ldatanames]; %IEB ADDED this line 
varnames = cellstr(varnames); %IEB ADDED line to meet requirments of 'RowNames'
% IEB Added line below 
T5= array2table(momYOY','VariableNames', label4, 'RowNames', varnames);
disp(T5); % IEB: ADDED this line.
