function [ADTP]=adtp(data,F, varargin)
%This program computes the average duration in a time series from trough to
%peak according to the Bry-Boschan identification method. It requires the
%programm file brybos. The input data can not have empty observations
%The user may alternatively specify a dating input where (1) stands for peak, 
%(-1) for a trough and (0) else (input for varargin as T*1 vector). It must have the same 
%dimensions as the data and can not have empty observations.

% The user must input the data as a T*1 vector and speecify the frequency
% F=0 for monthly data
% F=1 for quarterly data
% F=2 for yearly data
% The input data can not have empty observations.

%The output is the average duration for series m.

%Program written by Sebastian Weber, Graduate Institute of International
%Studies, Geneva

warning off MATLAB:divideByZero

if nargin==2
   date=brybos(data,F);
else
    date=varargin{:};
end

P=find(date(:,1)>0); 
T=find(date(:,1)<0);
[p1 k]=size(P);
[t1 k]=size(T);

if t1==0
        ADTP=0/0;
elseif p1==0
        ADTP=0/0;    
elseif P(1,1)>T(1,1)
        for j=1:p1
           Dur(j,1)=P(j,1)-T(j,1);
        end
        ADTP=sum(Dur)/p1;
else
    if p1<2
         ADTP=0/0;  
     else
        for j=2:p1
           Dur(j-1,1)=P(j,1)-T(j-1,1);
        end
        ADTP=sum(Dur)/(p1-1);   %average duration trough to peak 
    end
end


warning on MATLAB:divideByZero