function [GRRATETP]=GRRATETP(data,F,G,varargin)
%This program computes the average growth rate (rise) in a time series from trough to
%peak according to the Bry-Boschan identification method. It requires the
%programm file brybos. The input data can not have empty observations
%The user may alternatively specify a dating input where (1) stands for peak, 
%(-1) for a trough and (0) else (input for varargin as T*1 vector). It must have the same 
%dimensions as the data and can not have empty observations.

% The user must input the data as a T*1 vector and speecify the frequency
% F=0 for monthly data
% F=1 for quarterly data
% F=2 for yearly data
% The input data can not have empty observations.

% G=1 the growth rate is calculating using continous compounding.
% G=0 the growth rate is computed year-to-year change and taking the
% average over the period.

%The output is the average growth rate for series m from trough to peak.

%Program written by Sebastian Weber, Graduate Institute of International
%Studies, Geneva

warning off MATLAB:divideByZero


if nargin==2
   date=brybos(data,F);
else
    date=varargin{:};
end

P=find(date(:,1)>0); 
T=find(date(:,1)<0);
[p1 k]=size(P);
[t1 k]=size(T);

if G==1
if t1==0
        GRRATETP=0/0;
elseif p1==0
        GRRATETP=0/0;
elseif P(1,1)>T(1,1)
        for j=1:p1
                Rise(j,1)=((data(P(j,1),1)./data(T(j,1),1))^(1/(P(j,1)-T(j,1)))-1)*100;
        end
        GRRATETP=mean(Rise);
        clear Rise 
else
      if p1<2
        GRRATETP=0/0;
      else
        for j=1:p1-1
        Rise(j,1)=((data(P(j+1,1),1)./data(T(j,1),1))^(1/(P(j+1,1)-T(j,1)))-1)*100;
        end
        GRRATETP=mean(Rise);  %average rise trough to peak
        clear Rise 
      end
end
elseif G==0
    if t1==0
        GRRATETP=0/0;
elseif p1==0
        GRRATETP=0/0;
elseif P(1,1)>T(1,1)
        for j=1:p1
            length=P(j,1)-T(j,1);
            for l=1:length
                growth(l,1)=((data(T(j,1)+l,1)-data(T(j,1)+l-1,1))/data(T(j,1)+l-1,1))*100;
            end
            Rise(j,1)=mean(growth);    %average over growth rates within a trough to peak
        end
        GRRATETP=mean(Rise);       % average of growth rates across the various trough to peak
        clear Rise growth
else
      if p1<2
        GRRATETP=0/0;
      else
        for j=1:p1-1
            length=P(j+1,1)-T(j,1);
            for l=1:length
                growth(l,1)=((data(T(j,1)+l,1)-data(T(j,1)+l-1,1))/data(T(j,1)+l-1,1))*100;
            end
            Rise(j,1)=mean(growth);    %average over growth rates within a trough to peak
        end
        GRRATETP=mean(Rise);  % average of growth rates across the various trough to peak
        clear Rise growth
      end
end
end

warning on MATLAB:divideByZero

